v1alpha1

package
v1.0.0-cli.0...-a3b83d0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: AGPL-3.0, LGPL-3.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	ChunkService_CreateChunk_FullMethodName                   = "/chunk.v1alpha1.ChunkService/CreateChunk"
	ChunkService_GetChunk_FullMethodName                      = "/chunk.v1alpha1.ChunkService/GetChunk"
	ChunkService_UpdateChunk_FullMethodName                   = "/chunk.v1alpha1.ChunkService/UpdateChunk"
	ChunkService_ListChunks_FullMethodName                    = "/chunk.v1alpha1.ChunkService/ListChunks"
	ChunkService_CreateFlavor_FullMethodName                  = "/chunk.v1alpha1.ChunkService/CreateFlavor"
	ChunkService_CreateFlavorVersion_FullMethodName           = "/chunk.v1alpha1.ChunkService/CreateFlavorVersion"
	ChunkService_BuildFlavorVersion_FullMethodName            = "/chunk.v1alpha1.ChunkService/BuildFlavorVersion"
	ChunkService_GetUploadURL_FullMethodName                  = "/chunk.v1alpha1.ChunkService/GetUploadURL"
	ChunkService_GetSupportedMinecraftVersions_FullMethodName = "/chunk.v1alpha1.ChunkService/GetSupportedMinecraftVersions"
	ChunkService_UploadThumbnail_FullMethodName               = "/chunk.v1alpha1.ChunkService/UploadThumbnail"
	ChunkService_DeleteFlavor_FullMethodName                  = "/chunk.v1alpha1.ChunkService/DeleteFlavor"
	ChunkService_DeleteChunk_FullMethodName                   = "/chunk.v1alpha1.ChunkService/DeleteChunk"
)

Variables

var (
	BuildStatus_name = map[int32]string{
		0: "PENDING",
		1: "IMAGE_BUILD",
		2: "IMAGE_BUILD_FAILED",
		3: "CHECKPOINT_BUILD",
		4: "CHECKPOINT_BUILD_FAILED",
		5: "COMPLETED",
	}
	BuildStatus_value = map[string]int32{
		"PENDING":                 0,
		"IMAGE_BUILD":             1,
		"IMAGE_BUILD_FAILED":      2,
		"CHECKPOINT_BUILD":        3,
		"CHECKPOINT_BUILD_FAILED": 4,
		"COMPLETED":               5,
	}
)

Enum value maps for BuildStatus.

var ChunkService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "chunk.v1alpha1.ChunkService",
	HandlerType: (*ChunkServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateChunk",
			Handler:    _ChunkService_CreateChunk_Handler,
		},
		{
			MethodName: "GetChunk",
			Handler:    _ChunkService_GetChunk_Handler,
		},
		{
			MethodName: "UpdateChunk",
			Handler:    _ChunkService_UpdateChunk_Handler,
		},
		{
			MethodName: "ListChunks",
			Handler:    _ChunkService_ListChunks_Handler,
		},
		{
			MethodName: "CreateFlavor",
			Handler:    _ChunkService_CreateFlavor_Handler,
		},
		{
			MethodName: "CreateFlavorVersion",
			Handler:    _ChunkService_CreateFlavorVersion_Handler,
		},
		{
			MethodName: "BuildFlavorVersion",
			Handler:    _ChunkService_BuildFlavorVersion_Handler,
		},
		{
			MethodName: "GetUploadURL",
			Handler:    _ChunkService_GetUploadURL_Handler,
		},
		{
			MethodName: "GetSupportedMinecraftVersions",
			Handler:    _ChunkService_GetSupportedMinecraftVersions_Handler,
		},
		{
			MethodName: "UploadThumbnail",
			Handler:    _ChunkService_UploadThumbnail_Handler,
		},
		{
			MethodName: "DeleteFlavor",
			Handler:    _ChunkService_DeleteFlavor_Handler,
		},
		{
			MethodName: "DeleteChunk",
			Handler:    _ChunkService_DeleteChunk_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "chunk/v1alpha1/api.proto",
}

ChunkService_ServiceDesc is the grpc.ServiceDesc for ChunkService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_chunk_v1alpha1_api_proto protoreflect.FileDescriptor
var File_chunk_v1alpha1_types_proto protoreflect.FileDescriptor

Functions

func RegisterChunkServiceServer

func RegisterChunkServiceServer(s grpc.ServiceRegistrar, srv ChunkServiceServer)

Types

type BuildFlavorVersionRequest

type BuildFlavorVersionRequest struct {
	FlavorVersionId string `protobuf:"bytes,1,opt,name=flavor_version_id,json=flavorVersionId,proto3" json:"flavor_version_id,omitempty"`
	// contains filtered or unexported fields
}

func (*BuildFlavorVersionRequest) Descriptor deprecated

func (*BuildFlavorVersionRequest) Descriptor() ([]byte, []int)

Deprecated: Use BuildFlavorVersionRequest.ProtoReflect.Descriptor instead.

func (*BuildFlavorVersionRequest) GetFlavorVersionId

func (x *BuildFlavorVersionRequest) GetFlavorVersionId() string

func (*BuildFlavorVersionRequest) ProtoMessage

func (*BuildFlavorVersionRequest) ProtoMessage()

func (*BuildFlavorVersionRequest) ProtoReflect

func (*BuildFlavorVersionRequest) Reset

func (x *BuildFlavorVersionRequest) Reset()

func (*BuildFlavorVersionRequest) String

func (x *BuildFlavorVersionRequest) String() string

type BuildFlavorVersionResponse

type BuildFlavorVersionResponse struct {
	// contains filtered or unexported fields
}

func (*BuildFlavorVersionResponse) Descriptor deprecated

func (*BuildFlavorVersionResponse) Descriptor() ([]byte, []int)

Deprecated: Use BuildFlavorVersionResponse.ProtoReflect.Descriptor instead.

func (*BuildFlavorVersionResponse) ProtoMessage

func (*BuildFlavorVersionResponse) ProtoMessage()

func (*BuildFlavorVersionResponse) ProtoReflect

func (*BuildFlavorVersionResponse) Reset

func (x *BuildFlavorVersionResponse) Reset()

func (*BuildFlavorVersionResponse) String

func (x *BuildFlavorVersionResponse) String() string

type BuildStatus

type BuildStatus int32
const (
	BuildStatus_PENDING                 BuildStatus = 0
	BuildStatus_IMAGE_BUILD             BuildStatus = 1
	BuildStatus_IMAGE_BUILD_FAILED      BuildStatus = 2
	BuildStatus_CHECKPOINT_BUILD        BuildStatus = 3
	BuildStatus_CHECKPOINT_BUILD_FAILED BuildStatus = 4
	BuildStatus_COMPLETED               BuildStatus = 5
)

func (BuildStatus) Descriptor

func (BuildStatus) Enum

func (x BuildStatus) Enum() *BuildStatus

func (BuildStatus) EnumDescriptor deprecated

func (BuildStatus) EnumDescriptor() ([]byte, []int)

Deprecated: Use BuildStatus.Descriptor instead.

func (BuildStatus) Number

func (x BuildStatus) Number() protoreflect.EnumNumber

func (BuildStatus) String

func (x BuildStatus) String() string

func (BuildStatus) Type

type Chunk

type Chunk struct {
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Name of the chunk. can be up to 50 chars.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// Description briefly describes what the user can
	// expect when running the Chunk. can be up to 100
	// chars.
	Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	// Tags categorize the chunk. Possible values could
	// be: pvp, adventure, single-player
	// Note that the limit is currently 4.
	Tags      []string               `protobuf:"bytes,4,rep,name=tags,proto3" json:"tags,omitempty"`
	Flavors   []*Flavor              `protobuf:"bytes,5,rep,name=flavors,proto3" json:"flavors,omitempty"`
	Owner     *v1alpha1.User         `protobuf:"bytes,6,opt,name=owner,proto3" json:"owner,omitempty"`
	CreatedAt *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	UpdatedAt *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
	Thumbnail *Thumbnail             `protobuf:"bytes,9,opt,name=thumbnail,proto3" json:"thumbnail,omitempty"`
	DeletedAt *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=deleted_at,json=deletedAt,proto3" json:"deleted_at,omitempty"`
	// contains filtered or unexported fields
}

Chunk defines the configuration and metadata of user-generated content. This can be anything from a minigame to a freebuild server.

func (*Chunk) Descriptor deprecated

func (*Chunk) Descriptor() ([]byte, []int)

Deprecated: Use Chunk.ProtoReflect.Descriptor instead.

func (*Chunk) GetCreatedAt

func (x *Chunk) GetCreatedAt() *timestamppb.Timestamp

func (*Chunk) GetDeletedAt

func (x *Chunk) GetDeletedAt() *timestamppb.Timestamp

func (*Chunk) GetDescription

func (x *Chunk) GetDescription() string

func (*Chunk) GetFlavors

func (x *Chunk) GetFlavors() []*Flavor

func (*Chunk) GetId

func (x *Chunk) GetId() string

func (*Chunk) GetName

func (x *Chunk) GetName() string

func (*Chunk) GetOwner

func (x *Chunk) GetOwner() *v1alpha1.User

func (*Chunk) GetTags

func (x *Chunk) GetTags() []string

func (*Chunk) GetThumbnail

func (x *Chunk) GetThumbnail() *Thumbnail

func (*Chunk) GetUpdatedAt

func (x *Chunk) GetUpdatedAt() *timestamppb.Timestamp

func (*Chunk) ProtoMessage

func (*Chunk) ProtoMessage()

func (*Chunk) ProtoReflect

func (x *Chunk) ProtoReflect() protoreflect.Message

func (*Chunk) Reset

func (x *Chunk) Reset()

func (*Chunk) String

func (x *Chunk) String() string

type ChunkServiceClient

type ChunkServiceClient interface {
	// CreateChunk creates a new chunk without any flavors.
	// chunks that do not have any flavors will be deleted
	// after some time.
	//
	// Defined error codes:
	// - INVALID_ARGUMENT:
	//   - name is invalid
	//   - too many tags have been provided
	//   - name exceeds the maximum amount of allowed chars
	//   - description exceeds the maximum amount of allowed chars.
	CreateChunk(ctx context.Context, in *CreateChunkRequest, opts ...grpc.CallOption) (*CreateChunkResponse, error)
	// GetChunk returns the chunk specified by the provided id.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - chunk with the provided id does not exist
	//
	// - INVALID_ARGUMENT:
	//   - id is invalid
	GetChunk(ctx context.Context, in *GetChunkRequest, opts ...grpc.CallOption) (*GetChunkResponse, error)
	// UpdateChunk updates the fields of the given chunk.
	// Note that tags will be completely replaced with the
	// provided ones.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - chunk with the provided id does not exist or is deleted
	//
	// - INVALID_ARGUMENT:
	//   - chunk id is invalid
	//   - name is invalid
	//   - too many tags have been provided
	//   - name exceeds the maximum amount of allowed chars
	//   - description exceeds the maximum amount of allowed chars.
	UpdateChunk(ctx context.Context, in *UpdateChunkRequest, opts ...grpc.CallOption) (*UpdateChunkResponse, error)
	// ListChunks lists all available Chunks.
	ListChunks(ctx context.Context, in *ListChunksRequest, opts ...grpc.CallOption) (*ListChunksResponse, error)
	// CreateFlavor creates a new flavor for a given chunk.
	//
	// Defined error codes:
	// - ALREADY_EXISTS:
	//   - a flavor with the given name already exists for this chunk.
	//     this error will also be returned if the flavor is currently
	//     in the process of being deleted.
	//
	// - INVALID_ARGUMENT:
	//   - the provided chunk id is invalid
	//   - the provided flavor name is invalid
	CreateFlavor(ctx context.Context, in *CreateFlavorRequest, opts ...grpc.CallOption) (*CreateFlavorResponse, error)
	// CreateFlavorVersion creates a new flavor version for a
	// given flavor by determining the added, changed and removed
	// files. it also prevents version duplicates, meaning either
	// version numbers or the provided set of files match with
	// an already existing version.
	//
	// Defined error codes:
	// - NOT_FOUND
	//   - the affected flavor does not exist
	//
	// - ALREADY_EXISTS:
	//   - the flavor version about to be created is already present
	//   - a version with the exact same set of files already exists
	//
	// - FAILED_PRECONDITION:
	//   - the provided version hash does not match with the provided file hashes
	CreateFlavorVersion(ctx context.Context, in *CreateFlavorVersionRequest, opts ...grpc.CallOption) (*CreateFlavorVersionResponse, error)
	// BuildFlavorVersion will initiate the process for building a checkpoint image.
	// there are multiple steps involved. Calling this endpoint multiple times will
	// have no effect, if the build process is ongoing. Build status can be retrieved
	// by getting the flavor version.
	//
	// Defined error codes:
	// - FAILED_PRECONDITION:
	//   - the flavor version files have not been uploaded yet.
	BuildFlavorVersion(ctx context.Context, in *BuildFlavorVersionRequest, opts ...grpc.CallOption) (*BuildFlavorVersionResponse, error)
	// GetUploadURL returns a presigned URL for use with a S3 client. If the expiry date
	// is reached the client can call this endpoint again and will receive a new valid
	// URL. Calling this endpoint multiple without the expiry date being reached will
	// lead to the same URL being returned.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - the targeted flavor version does not exist
	//
	// - ALREADY_EXISTS:
	//   - the tarball has already been uploaded
	//
	// - INVALID_ARGUMENT:
	//   - the provided flavor version id is invalid
	//   - the provided tarball hash is empty or does not meet the requirements.
	//     for more information about what requirements are expected see tarball_hash
	//     documentation of GetUploadURLRequest
	GetUploadURL(ctx context.Context, in *GetUploadURLRequest, opts ...grpc.CallOption) (*GetUploadURLResponse, error)
	GetSupportedMinecraftVersions(ctx context.Context, in *GetSupportedMinecraftVersionsRequest, opts ...grpc.CallOption) (*GetSupportedMinecraftVersionsResponse, error)
	// UploadThumbnail uploads the given PNG image. Formats other than PNG are not supported.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - the targeted chunk does not exist
	//
	// - INVALID_ARGUMENT:
	//   - chunk id is invalid
	//   - thumbnail image must be PNG
	//   - thumbnail size must be 512x512 pixels
	//   - thumbnail size too big
	UploadThumbnail(ctx context.Context, in *UploadThumbnailRequest, opts ...grpc.CallOption) (*UploadThumbnailResponse, error)
	// DeleteFlavor initiates the process for a Flavor to be deleted. Deletion does not happen
	// instantaneously, it can take a few minutes for a Flavor to be fully deleted. During this
	// time any interaction with the flavor is blocked. This means that updates are no longer
	// possible and creating Instances based on the Flavors versions is also not possible.
	//
	// Defined error codes:
	// - INVALID_ARGUMENT:
	//   - flavor id is invalid
	DeleteFlavor(ctx context.Context, in *DeleteFlavorRequest, opts ...grpc.CallOption) (*DeleteFlavorResponse, error)
	// DeleteChunk initiates the process for a Chunk to be deleted. This will also delete all
	// Flavors associated with this Chunk. Deletion does not happen instantaneously, it can take
	// a few minutes for a Chunk to be fully deleted. During this time any interaction with the
	// Chunk and its Flavors is blocked. This means that updates are no longer possible and creating
	// Instances based on the Flavors versions is also not possible.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - the targeted chunk does not exist
	//
	// - INVALID_ARGUMENT:
	//   - chunk id is invalid
	DeleteChunk(ctx context.Context, in *DeleteChunkRequest, opts ...grpc.CallOption) (*DeleteChunkResponse, error)
}

ChunkServiceClient is the client API for ChunkService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

ChunkService provides the public api for interacting with Chunks and flavors of Chunks.

type ChunkServiceServer

type ChunkServiceServer interface {
	// CreateChunk creates a new chunk without any flavors.
	// chunks that do not have any flavors will be deleted
	// after some time.
	//
	// Defined error codes:
	// - INVALID_ARGUMENT:
	//   - name is invalid
	//   - too many tags have been provided
	//   - name exceeds the maximum amount of allowed chars
	//   - description exceeds the maximum amount of allowed chars.
	CreateChunk(context.Context, *CreateChunkRequest) (*CreateChunkResponse, error)
	// GetChunk returns the chunk specified by the provided id.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - chunk with the provided id does not exist
	//
	// - INVALID_ARGUMENT:
	//   - id is invalid
	GetChunk(context.Context, *GetChunkRequest) (*GetChunkResponse, error)
	// UpdateChunk updates the fields of the given chunk.
	// Note that tags will be completely replaced with the
	// provided ones.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - chunk with the provided id does not exist or is deleted
	//
	// - INVALID_ARGUMENT:
	//   - chunk id is invalid
	//   - name is invalid
	//   - too many tags have been provided
	//   - name exceeds the maximum amount of allowed chars
	//   - description exceeds the maximum amount of allowed chars.
	UpdateChunk(context.Context, *UpdateChunkRequest) (*UpdateChunkResponse, error)
	// ListChunks lists all available Chunks.
	ListChunks(context.Context, *ListChunksRequest) (*ListChunksResponse, error)
	// CreateFlavor creates a new flavor for a given chunk.
	//
	// Defined error codes:
	// - ALREADY_EXISTS:
	//   - a flavor with the given name already exists for this chunk.
	//     this error will also be returned if the flavor is currently
	//     in the process of being deleted.
	//
	// - INVALID_ARGUMENT:
	//   - the provided chunk id is invalid
	//   - the provided flavor name is invalid
	CreateFlavor(context.Context, *CreateFlavorRequest) (*CreateFlavorResponse, error)
	// CreateFlavorVersion creates a new flavor version for a
	// given flavor by determining the added, changed and removed
	// files. it also prevents version duplicates, meaning either
	// version numbers or the provided set of files match with
	// an already existing version.
	//
	// Defined error codes:
	// - NOT_FOUND
	//   - the affected flavor does not exist
	//
	// - ALREADY_EXISTS:
	//   - the flavor version about to be created is already present
	//   - a version with the exact same set of files already exists
	//
	// - FAILED_PRECONDITION:
	//   - the provided version hash does not match with the provided file hashes
	CreateFlavorVersion(context.Context, *CreateFlavorVersionRequest) (*CreateFlavorVersionResponse, error)
	// BuildFlavorVersion will initiate the process for building a checkpoint image.
	// there are multiple steps involved. Calling this endpoint multiple times will
	// have no effect, if the build process is ongoing. Build status can be retrieved
	// by getting the flavor version.
	//
	// Defined error codes:
	// - FAILED_PRECONDITION:
	//   - the flavor version files have not been uploaded yet.
	BuildFlavorVersion(context.Context, *BuildFlavorVersionRequest) (*BuildFlavorVersionResponse, error)
	// GetUploadURL returns a presigned URL for use with a S3 client. If the expiry date
	// is reached the client can call this endpoint again and will receive a new valid
	// URL. Calling this endpoint multiple without the expiry date being reached will
	// lead to the same URL being returned.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - the targeted flavor version does not exist
	//
	// - ALREADY_EXISTS:
	//   - the tarball has already been uploaded
	//
	// - INVALID_ARGUMENT:
	//   - the provided flavor version id is invalid
	//   - the provided tarball hash is empty or does not meet the requirements.
	//     for more information about what requirements are expected see tarball_hash
	//     documentation of GetUploadURLRequest
	GetUploadURL(context.Context, *GetUploadURLRequest) (*GetUploadURLResponse, error)
	GetSupportedMinecraftVersions(context.Context, *GetSupportedMinecraftVersionsRequest) (*GetSupportedMinecraftVersionsResponse, error)
	// UploadThumbnail uploads the given PNG image. Formats other than PNG are not supported.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - the targeted chunk does not exist
	//
	// - INVALID_ARGUMENT:
	//   - chunk id is invalid
	//   - thumbnail image must be PNG
	//   - thumbnail size must be 512x512 pixels
	//   - thumbnail size too big
	UploadThumbnail(context.Context, *UploadThumbnailRequest) (*UploadThumbnailResponse, error)
	// DeleteFlavor initiates the process for a Flavor to be deleted. Deletion does not happen
	// instantaneously, it can take a few minutes for a Flavor to be fully deleted. During this
	// time any interaction with the flavor is blocked. This means that updates are no longer
	// possible and creating Instances based on the Flavors versions is also not possible.
	//
	// Defined error codes:
	// - INVALID_ARGUMENT:
	//   - flavor id is invalid
	DeleteFlavor(context.Context, *DeleteFlavorRequest) (*DeleteFlavorResponse, error)
	// DeleteChunk initiates the process for a Chunk to be deleted. This will also delete all
	// Flavors associated with this Chunk. Deletion does not happen instantaneously, it can take
	// a few minutes for a Chunk to be fully deleted. During this time any interaction with the
	// Chunk and its Flavors is blocked. This means that updates are no longer possible and creating
	// Instances based on the Flavors versions is also not possible.
	//
	// Defined error codes:
	// - NOT_FOUND:
	//   - the targeted chunk does not exist
	//
	// - INVALID_ARGUMENT:
	//   - chunk id is invalid
	DeleteChunk(context.Context, *DeleteChunkRequest) (*DeleteChunkResponse, error)
	// contains filtered or unexported methods
}

ChunkServiceServer is the server API for ChunkService service. All implementations must embed UnimplementedChunkServiceServer for forward compatibility.

ChunkService provides the public api for interacting with Chunks and flavors of Chunks.

type CreateChunkRequest

type CreateChunkRequest struct {

	// Name of the chunk. can be up to 50 chars.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Description briefly describes what the user can
	// expect when running the Chunk. can be up to 100
	// chars.
	Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	// Tags categorize the chunk. Possible values could
	// be: pvp, adventure, single-player
	// Note that the limit is currently 4.
	Tags []string `protobuf:"bytes,3,rep,name=tags,proto3" json:"tags,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateChunkRequest) Descriptor deprecated

func (*CreateChunkRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateChunkRequest.ProtoReflect.Descriptor instead.

func (*CreateChunkRequest) GetDescription

func (x *CreateChunkRequest) GetDescription() string

func (*CreateChunkRequest) GetName

func (x *CreateChunkRequest) GetName() string

func (*CreateChunkRequest) GetTags

func (x *CreateChunkRequest) GetTags() []string

func (*CreateChunkRequest) ProtoMessage

func (*CreateChunkRequest) ProtoMessage()

func (*CreateChunkRequest) ProtoReflect

func (x *CreateChunkRequest) ProtoReflect() protoreflect.Message

func (*CreateChunkRequest) Reset

func (x *CreateChunkRequest) Reset()

func (*CreateChunkRequest) String

func (x *CreateChunkRequest) String() string

type CreateChunkResponse

type CreateChunkResponse struct {
	Chunk *Chunk `protobuf:"bytes,1,opt,name=chunk,proto3" json:"chunk,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateChunkResponse) Descriptor deprecated

func (*CreateChunkResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateChunkResponse.ProtoReflect.Descriptor instead.

func (*CreateChunkResponse) GetChunk

func (x *CreateChunkResponse) GetChunk() *Chunk

func (*CreateChunkResponse) ProtoMessage

func (*CreateChunkResponse) ProtoMessage()

func (*CreateChunkResponse) ProtoReflect

func (x *CreateChunkResponse) ProtoReflect() protoreflect.Message

func (*CreateChunkResponse) Reset

func (x *CreateChunkResponse) Reset()

func (*CreateChunkResponse) String

func (x *CreateChunkResponse) String() string

type CreateFlavorRequest

type CreateFlavorRequest struct {
	ChunkId string `protobuf:"bytes,1,opt,name=chunk_id,json=chunkId,proto3" json:"chunk_id,omitempty"`
	Name    string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateFlavorRequest) Descriptor deprecated

func (*CreateFlavorRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateFlavorRequest.ProtoReflect.Descriptor instead.

func (*CreateFlavorRequest) GetChunkId

func (x *CreateFlavorRequest) GetChunkId() string

func (*CreateFlavorRequest) GetName

func (x *CreateFlavorRequest) GetName() string

func (*CreateFlavorRequest) ProtoMessage

func (*CreateFlavorRequest) ProtoMessage()

func (*CreateFlavorRequest) ProtoReflect

func (x *CreateFlavorRequest) ProtoReflect() protoreflect.Message

func (*CreateFlavorRequest) Reset

func (x *CreateFlavorRequest) Reset()

func (*CreateFlavorRequest) String

func (x *CreateFlavorRequest) String() string

type CreateFlavorResponse

type CreateFlavorResponse struct {
	Flavor *Flavor `protobuf:"bytes,1,opt,name=flavor,proto3" json:"flavor,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateFlavorResponse) Descriptor deprecated

func (*CreateFlavorResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateFlavorResponse.ProtoReflect.Descriptor instead.

func (*CreateFlavorResponse) GetFlavor

func (x *CreateFlavorResponse) GetFlavor() *Flavor

func (*CreateFlavorResponse) ProtoMessage

func (*CreateFlavorResponse) ProtoMessage()

func (*CreateFlavorResponse) ProtoReflect

func (x *CreateFlavorResponse) ProtoReflect() protoreflect.Message

func (*CreateFlavorResponse) Reset

func (x *CreateFlavorResponse) Reset()

func (*CreateFlavorResponse) String

func (x *CreateFlavorResponse) String() string

type CreateFlavorVersionRequest

type CreateFlavorVersionRequest struct {
	FlavorId string         `protobuf:"bytes,1,opt,name=flavor_id,json=flavorId,proto3" json:"flavor_id,omitempty"`
	Version  *FlavorVersion `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateFlavorVersionRequest) Descriptor deprecated

func (*CreateFlavorVersionRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateFlavorVersionRequest.ProtoReflect.Descriptor instead.

func (*CreateFlavorVersionRequest) GetFlavorId

func (x *CreateFlavorVersionRequest) GetFlavorId() string

func (*CreateFlavorVersionRequest) GetVersion

func (x *CreateFlavorVersionRequest) GetVersion() *FlavorVersion

func (*CreateFlavorVersionRequest) ProtoMessage

func (*CreateFlavorVersionRequest) ProtoMessage()

func (*CreateFlavorVersionRequest) ProtoReflect

func (*CreateFlavorVersionRequest) Reset

func (x *CreateFlavorVersionRequest) Reset()

func (*CreateFlavorVersionRequest) String

func (x *CreateFlavorVersionRequest) String() string

type CreateFlavorVersionResponse

type CreateFlavorVersionResponse struct {
	Version      *FlavorVersion `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
	ChangedFiles []*FileHashes  `protobuf:"bytes,2,rep,name=changed_files,json=changedFiles,proto3" json:"changed_files,omitempty"`
	RemovedFiles []*FileHashes  `protobuf:"bytes,3,rep,name=removed_files,json=removedFiles,proto3" json:"removed_files,omitempty"`
	AddedFiles   []*FileHashes  `protobuf:"bytes,4,rep,name=added_files,json=addedFiles,proto3" json:"added_files,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateFlavorVersionResponse) Descriptor deprecated

func (*CreateFlavorVersionResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreateFlavorVersionResponse.ProtoReflect.Descriptor instead.

func (*CreateFlavorVersionResponse) GetAddedFiles

func (x *CreateFlavorVersionResponse) GetAddedFiles() []*FileHashes

func (*CreateFlavorVersionResponse) GetChangedFiles

func (x *CreateFlavorVersionResponse) GetChangedFiles() []*FileHashes

func (*CreateFlavorVersionResponse) GetRemovedFiles

func (x *CreateFlavorVersionResponse) GetRemovedFiles() []*FileHashes

func (*CreateFlavorVersionResponse) GetVersion

func (x *CreateFlavorVersionResponse) GetVersion() *FlavorVersion

func (*CreateFlavorVersionResponse) ProtoMessage

func (*CreateFlavorVersionResponse) ProtoMessage()

func (*CreateFlavorVersionResponse) ProtoReflect

func (*CreateFlavorVersionResponse) Reset

func (x *CreateFlavorVersionResponse) Reset()

func (*CreateFlavorVersionResponse) String

func (x *CreateFlavorVersionResponse) String() string

type DeleteChunkRequest

type DeleteChunkRequest struct {
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteChunkRequest) Descriptor deprecated

func (*DeleteChunkRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteChunkRequest.ProtoReflect.Descriptor instead.

func (*DeleteChunkRequest) GetId

func (x *DeleteChunkRequest) GetId() string

func (*DeleteChunkRequest) ProtoMessage

func (*DeleteChunkRequest) ProtoMessage()

func (*DeleteChunkRequest) ProtoReflect

func (x *DeleteChunkRequest) ProtoReflect() protoreflect.Message

func (*DeleteChunkRequest) Reset

func (x *DeleteChunkRequest) Reset()

func (*DeleteChunkRequest) String

func (x *DeleteChunkRequest) String() string

type DeleteChunkResponse

type DeleteChunkResponse struct {
	// contains filtered or unexported fields
}

func (*DeleteChunkResponse) Descriptor deprecated

func (*DeleteChunkResponse) Descriptor() ([]byte, []int)

Deprecated: Use DeleteChunkResponse.ProtoReflect.Descriptor instead.

func (*DeleteChunkResponse) ProtoMessage

func (*DeleteChunkResponse) ProtoMessage()

func (*DeleteChunkResponse) ProtoReflect

func (x *DeleteChunkResponse) ProtoReflect() protoreflect.Message

func (*DeleteChunkResponse) Reset

func (x *DeleteChunkResponse) Reset()

func (*DeleteChunkResponse) String

func (x *DeleteChunkResponse) String() string

type DeleteFlavorRequest

type DeleteFlavorRequest struct {
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteFlavorRequest) Descriptor deprecated

func (*DeleteFlavorRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteFlavorRequest.ProtoReflect.Descriptor instead.

func (*DeleteFlavorRequest) GetId

func (x *DeleteFlavorRequest) GetId() string

func (*DeleteFlavorRequest) ProtoMessage

func (*DeleteFlavorRequest) ProtoMessage()

func (*DeleteFlavorRequest) ProtoReflect

func (x *DeleteFlavorRequest) ProtoReflect() protoreflect.Message

func (*DeleteFlavorRequest) Reset

func (x *DeleteFlavorRequest) Reset()

func (*DeleteFlavorRequest) String

func (x *DeleteFlavorRequest) String() string

type DeleteFlavorResponse

type DeleteFlavorResponse struct {
	// contains filtered or unexported fields
}

func (*DeleteFlavorResponse) Descriptor deprecated

func (*DeleteFlavorResponse) Descriptor() ([]byte, []int)

Deprecated: Use DeleteFlavorResponse.ProtoReflect.Descriptor instead.

func (*DeleteFlavorResponse) ProtoMessage

func (*DeleteFlavorResponse) ProtoMessage()

func (*DeleteFlavorResponse) ProtoReflect

func (x *DeleteFlavorResponse) ProtoReflect() protoreflect.Message

func (*DeleteFlavorResponse) Reset

func (x *DeleteFlavorResponse) Reset()

func (*DeleteFlavorResponse) String

func (x *DeleteFlavorResponse) String() string

type File

type File struct {
	Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
	Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

func (*File) Descriptor deprecated

func (*File) Descriptor() ([]byte, []int)

Deprecated: Use File.ProtoReflect.Descriptor instead.

func (*File) GetData

func (x *File) GetData() []byte

func (*File) GetPath

func (x *File) GetPath() string

func (*File) ProtoMessage

func (*File) ProtoMessage()

func (*File) ProtoReflect

func (x *File) ProtoReflect() protoreflect.Message

func (*File) Reset

func (x *File) Reset()

func (*File) String

func (x *File) String() string

type FileHashes

type FileHashes struct {
	Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
	Hash string `protobuf:"bytes,2,opt,name=hash,proto3" json:"hash,omitempty"`
	// contains filtered or unexported fields
}

func (*FileHashes) Descriptor deprecated

func (*FileHashes) Descriptor() ([]byte, []int)

Deprecated: Use FileHashes.ProtoReflect.Descriptor instead.

func (*FileHashes) GetHash

func (x *FileHashes) GetHash() string

func (*FileHashes) GetPath

func (x *FileHashes) GetPath() string

func (*FileHashes) ProtoMessage

func (*FileHashes) ProtoMessage()

func (*FileHashes) ProtoReflect

func (x *FileHashes) ProtoReflect() protoreflect.Message

func (*FileHashes) Reset

func (x *FileHashes) Reset()

func (*FileHashes) String

func (x *FileHashes) String() string

type Flavor

type Flavor struct {
	Id        string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Name      string                 `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Versions  []*FlavorVersion       `protobuf:"bytes,3,rep,name=versions,proto3" json:"versions,omitempty"`
	CreatedAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	UpdatedAt *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
	// contains filtered or unexported fields
}

func (*Flavor) Descriptor deprecated

func (*Flavor) Descriptor() ([]byte, []int)

Deprecated: Use Flavor.ProtoReflect.Descriptor instead.

func (*Flavor) GetCreatedAt

func (x *Flavor) GetCreatedAt() *timestamppb.Timestamp

func (*Flavor) GetId

func (x *Flavor) GetId() string

func (*Flavor) GetName

func (x *Flavor) GetName() string

func (*Flavor) GetUpdatedAt

func (x *Flavor) GetUpdatedAt() *timestamppb.Timestamp

func (*Flavor) GetVersions

func (x *Flavor) GetVersions() []*FlavorVersion

func (*Flavor) ProtoMessage

func (*Flavor) ProtoMessage()

func (*Flavor) ProtoReflect

func (x *Flavor) ProtoReflect() protoreflect.Message

func (*Flavor) Reset

func (x *Flavor) Reset()

func (*Flavor) String

func (x *Flavor) String() string

type FlavorVersion

type FlavorVersion struct {
	Id               string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Version          string                 `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
	Hash             string                 `protobuf:"bytes,4,opt,name=hash,proto3" json:"hash,omitempty"`
	FileHashes       []*FileHashes          `protobuf:"bytes,5,rep,name=file_hashes,json=fileHashes,proto3" json:"file_hashes,omitempty"`
	BuildStatus      BuildStatus            `` /* 127-byte string literal not displayed */
	FilesUploaded    bool                   `protobuf:"varint,8,opt,name=files_uploaded,json=filesUploaded,proto3" json:"files_uploaded,omitempty"`
	MinecraftVersion string                 `protobuf:"bytes,9,opt,name=minecraft_version,json=minecraftVersion,proto3" json:"minecraft_version,omitempty"`
	CreatedAt        *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	// contains filtered or unexported fields
}

func (*FlavorVersion) Descriptor deprecated

func (*FlavorVersion) Descriptor() ([]byte, []int)

Deprecated: Use FlavorVersion.ProtoReflect.Descriptor instead.

func (*FlavorVersion) GetBuildStatus

func (x *FlavorVersion) GetBuildStatus() BuildStatus

func (*FlavorVersion) GetCreatedAt

func (x *FlavorVersion) GetCreatedAt() *timestamppb.Timestamp

func (*FlavorVersion) GetFileHashes

func (x *FlavorVersion) GetFileHashes() []*FileHashes

func (*FlavorVersion) GetFilesUploaded

func (x *FlavorVersion) GetFilesUploaded() bool

func (*FlavorVersion) GetHash

func (x *FlavorVersion) GetHash() string

func (*FlavorVersion) GetId

func (x *FlavorVersion) GetId() string

func (*FlavorVersion) GetMinecraftVersion

func (x *FlavorVersion) GetMinecraftVersion() string

func (*FlavorVersion) GetVersion

func (x *FlavorVersion) GetVersion() string

func (*FlavorVersion) ProtoMessage

func (*FlavorVersion) ProtoMessage()

func (*FlavorVersion) ProtoReflect

func (x *FlavorVersion) ProtoReflect() protoreflect.Message

func (*FlavorVersion) Reset

func (x *FlavorVersion) Reset()

func (*FlavorVersion) String

func (x *FlavorVersion) String() string

type GetChunkRequest

type GetChunkRequest struct {
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*GetChunkRequest) Descriptor deprecated

func (*GetChunkRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetChunkRequest.ProtoReflect.Descriptor instead.

func (*GetChunkRequest) GetId

func (x *GetChunkRequest) GetId() string

func (*GetChunkRequest) ProtoMessage

func (*GetChunkRequest) ProtoMessage()

func (*GetChunkRequest) ProtoReflect

func (x *GetChunkRequest) ProtoReflect() protoreflect.Message

func (*GetChunkRequest) Reset

func (x *GetChunkRequest) Reset()

func (*GetChunkRequest) String

func (x *GetChunkRequest) String() string

type GetChunkResponse

type GetChunkResponse struct {
	Chunk *Chunk `protobuf:"bytes,1,opt,name=chunk,proto3" json:"chunk,omitempty"`
	// contains filtered or unexported fields
}

func (*GetChunkResponse) Descriptor deprecated

func (*GetChunkResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetChunkResponse.ProtoReflect.Descriptor instead.

func (*GetChunkResponse) GetChunk

func (x *GetChunkResponse) GetChunk() *Chunk

func (*GetChunkResponse) ProtoMessage

func (*GetChunkResponse) ProtoMessage()

func (*GetChunkResponse) ProtoReflect

func (x *GetChunkResponse) ProtoReflect() protoreflect.Message

func (*GetChunkResponse) Reset

func (x *GetChunkResponse) Reset()

func (*GetChunkResponse) String

func (x *GetChunkResponse) String() string

type GetSupportedMinecraftVersionsRequest

type GetSupportedMinecraftVersionsRequest struct {
	// contains filtered or unexported fields
}

func (*GetSupportedMinecraftVersionsRequest) Descriptor deprecated

func (*GetSupportedMinecraftVersionsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetSupportedMinecraftVersionsRequest.ProtoReflect.Descriptor instead.

func (*GetSupportedMinecraftVersionsRequest) ProtoMessage

func (*GetSupportedMinecraftVersionsRequest) ProtoMessage()

func (*GetSupportedMinecraftVersionsRequest) ProtoReflect

func (*GetSupportedMinecraftVersionsRequest) Reset

func (*GetSupportedMinecraftVersionsRequest) String

type GetSupportedMinecraftVersionsResponse

type GetSupportedMinecraftVersionsResponse struct {
	Versions []string `protobuf:"bytes,1,rep,name=versions,proto3" json:"versions,omitempty"`
	// contains filtered or unexported fields
}

func (*GetSupportedMinecraftVersionsResponse) Descriptor deprecated

func (*GetSupportedMinecraftVersionsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetSupportedMinecraftVersionsResponse.ProtoReflect.Descriptor instead.

func (*GetSupportedMinecraftVersionsResponse) GetVersions

func (x *GetSupportedMinecraftVersionsResponse) GetVersions() []string

func (*GetSupportedMinecraftVersionsResponse) ProtoMessage

func (*GetSupportedMinecraftVersionsResponse) ProtoMessage()

func (*GetSupportedMinecraftVersionsResponse) ProtoReflect

func (*GetSupportedMinecraftVersionsResponse) Reset

func (*GetSupportedMinecraftVersionsResponse) String

type GetUploadURLRequest

type GetUploadURLRequest struct {
	FlavorVersionId string `protobuf:"bytes,1,opt,name=flavor_version_id,json=flavorVersionId,proto3" json:"flavor_version_id,omitempty"`
	// tarball_hash is the base64 encoded, 256-bit SHA256 digest of the tarball
	TarballHash      string `protobuf:"bytes,2,opt,name=tarball_hash,json=tarballHash,proto3" json:"tarball_hash,omitempty"`
	TarballSizeBytes uint64 `protobuf:"varint,3,opt,name=tarball_size_bytes,json=tarballSizeBytes,proto3" json:"tarball_size_bytes,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUploadURLRequest) Descriptor deprecated

func (*GetUploadURLRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetUploadURLRequest.ProtoReflect.Descriptor instead.

func (*GetUploadURLRequest) GetFlavorVersionId

func (x *GetUploadURLRequest) GetFlavorVersionId() string

func (*GetUploadURLRequest) GetTarballHash

func (x *GetUploadURLRequest) GetTarballHash() string

func (*GetUploadURLRequest) GetTarballSizeBytes

func (x *GetUploadURLRequest) GetTarballSizeBytes() uint64

func (*GetUploadURLRequest) ProtoMessage

func (*GetUploadURLRequest) ProtoMessage()

func (*GetUploadURLRequest) ProtoReflect

func (x *GetUploadURLRequest) ProtoReflect() protoreflect.Message

func (*GetUploadURLRequest) Reset

func (x *GetUploadURLRequest) Reset()

func (*GetUploadURLRequest) String

func (x *GetUploadURLRequest) String() string

type GetUploadURLResponse

type GetUploadURLResponse struct {
	Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUploadURLResponse) Descriptor deprecated

func (*GetUploadURLResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetUploadURLResponse.ProtoReflect.Descriptor instead.

func (*GetUploadURLResponse) GetUrl

func (x *GetUploadURLResponse) GetUrl() string

func (*GetUploadURLResponse) ProtoMessage

func (*GetUploadURLResponse) ProtoMessage()

func (*GetUploadURLResponse) ProtoReflect

func (x *GetUploadURLResponse) ProtoReflect() protoreflect.Message

func (*GetUploadURLResponse) Reset

func (x *GetUploadURLResponse) Reset()

func (*GetUploadURLResponse) String

func (x *GetUploadURLResponse) String() string

type ListChunksRequest

type ListChunksRequest struct {
	PageSize  uint32 `protobuf:"varint,1,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	PageToken string `protobuf:"bytes,2,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*ListChunksRequest) Descriptor deprecated

func (*ListChunksRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListChunksRequest.ProtoReflect.Descriptor instead.

func (*ListChunksRequest) GetPageSize

func (x *ListChunksRequest) GetPageSize() uint32

func (*ListChunksRequest) GetPageToken

func (x *ListChunksRequest) GetPageToken() string

func (*ListChunksRequest) ProtoMessage

func (*ListChunksRequest) ProtoMessage()

func (*ListChunksRequest) ProtoReflect

func (x *ListChunksRequest) ProtoReflect() protoreflect.Message

func (*ListChunksRequest) Reset

func (x *ListChunksRequest) Reset()

func (*ListChunksRequest) String

func (x *ListChunksRequest) String() string

type ListChunksResponse

type ListChunksResponse struct {
	Chunks        []*Chunk `protobuf:"bytes,1,rep,name=chunks,proto3" json:"chunks,omitempty"`
	NextPageToken string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*ListChunksResponse) Descriptor deprecated

func (*ListChunksResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListChunksResponse.ProtoReflect.Descriptor instead.

func (*ListChunksResponse) GetChunks

func (x *ListChunksResponse) GetChunks() []*Chunk

func (*ListChunksResponse) GetNextPageToken

func (x *ListChunksResponse) GetNextPageToken() string

func (*ListChunksResponse) ProtoMessage

func (*ListChunksResponse) ProtoMessage()

func (*ListChunksResponse) ProtoReflect

func (x *ListChunksResponse) ProtoReflect() protoreflect.Message

func (*ListChunksResponse) Reset

func (x *ListChunksResponse) Reset()

func (*ListChunksResponse) String

func (x *ListChunksResponse) String() string

type Thumbnail

type Thumbnail struct {

	// hash is the xxh3 hash of the image
	Hash string `protobuf:"bytes,1,opt,name=hash,proto3" json:"hash,omitempty"`
	// contains filtered or unexported fields
}

func (*Thumbnail) Descriptor deprecated

func (*Thumbnail) Descriptor() ([]byte, []int)

Deprecated: Use Thumbnail.ProtoReflect.Descriptor instead.

func (*Thumbnail) GetHash

func (x *Thumbnail) GetHash() string

func (*Thumbnail) ProtoMessage

func (*Thumbnail) ProtoMessage()

func (*Thumbnail) ProtoReflect

func (x *Thumbnail) ProtoReflect() protoreflect.Message

func (*Thumbnail) Reset

func (x *Thumbnail) Reset()

func (*Thumbnail) String

func (x *Thumbnail) String() string

type UnimplementedChunkServiceServer

type UnimplementedChunkServiceServer struct{}

UnimplementedChunkServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedChunkServiceServer) BuildFlavorVersion

func (UnimplementedChunkServiceServer) CreateChunk

func (UnimplementedChunkServiceServer) CreateFlavor

func (UnimplementedChunkServiceServer) DeleteChunk

func (UnimplementedChunkServiceServer) DeleteFlavor

func (UnimplementedChunkServiceServer) GetChunk

func (UnimplementedChunkServiceServer) GetUploadURL

func (UnimplementedChunkServiceServer) ListChunks

func (UnimplementedChunkServiceServer) UpdateChunk

func (UnimplementedChunkServiceServer) UploadThumbnail

type UnsafeChunkServiceServer

type UnsafeChunkServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeChunkServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ChunkServiceServer will result in compilation errors.

type UpdateChunkRequest

type UpdateChunkRequest struct {
	Id          string   `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Name        string   `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Description string   `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	Tags        []string `protobuf:"bytes,4,rep,name=tags,proto3" json:"tags,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdateChunkRequest) Descriptor deprecated

func (*UpdateChunkRequest) Descriptor() ([]byte, []int)

Deprecated: Use UpdateChunkRequest.ProtoReflect.Descriptor instead.

func (*UpdateChunkRequest) GetDescription

func (x *UpdateChunkRequest) GetDescription() string

func (*UpdateChunkRequest) GetId

func (x *UpdateChunkRequest) GetId() string

func (*UpdateChunkRequest) GetName

func (x *UpdateChunkRequest) GetName() string

func (*UpdateChunkRequest) GetTags

func (x *UpdateChunkRequest) GetTags() []string

func (*UpdateChunkRequest) ProtoMessage

func (*UpdateChunkRequest) ProtoMessage()

func (*UpdateChunkRequest) ProtoReflect

func (x *UpdateChunkRequest) ProtoReflect() protoreflect.Message

func (*UpdateChunkRequest) Reset

func (x *UpdateChunkRequest) Reset()

func (*UpdateChunkRequest) String

func (x *UpdateChunkRequest) String() string

type UpdateChunkResponse

type UpdateChunkResponse struct {
	Chunk *Chunk `protobuf:"bytes,1,opt,name=chunk,proto3" json:"chunk,omitempty"`
	// contains filtered or unexported fields
}

func (*UpdateChunkResponse) Descriptor deprecated

func (*UpdateChunkResponse) Descriptor() ([]byte, []int)

Deprecated: Use UpdateChunkResponse.ProtoReflect.Descriptor instead.

func (*UpdateChunkResponse) GetChunk

func (x *UpdateChunkResponse) GetChunk() *Chunk

func (*UpdateChunkResponse) ProtoMessage

func (*UpdateChunkResponse) ProtoMessage()

func (*UpdateChunkResponse) ProtoReflect

func (x *UpdateChunkResponse) ProtoReflect() protoreflect.Message

func (*UpdateChunkResponse) Reset

func (x *UpdateChunkResponse) Reset()

func (*UpdateChunkResponse) String

func (x *UpdateChunkResponse) String() string

type UploadThumbnailRequest

type UploadThumbnailRequest struct {
	ChunkId string `protobuf:"bytes,1,opt,name=chunk_id,json=chunkId,proto3" json:"chunk_id,omitempty"`
	// image is the raw image bytes
	Image []byte `protobuf:"bytes,2,opt,name=image,proto3" json:"image,omitempty"`
	// contains filtered or unexported fields
}

func (*UploadThumbnailRequest) Descriptor deprecated

func (*UploadThumbnailRequest) Descriptor() ([]byte, []int)

Deprecated: Use UploadThumbnailRequest.ProtoReflect.Descriptor instead.

func (*UploadThumbnailRequest) GetChunkId

func (x *UploadThumbnailRequest) GetChunkId() string

func (*UploadThumbnailRequest) GetImage

func (x *UploadThumbnailRequest) GetImage() []byte

func (*UploadThumbnailRequest) ProtoMessage

func (*UploadThumbnailRequest) ProtoMessage()

func (*UploadThumbnailRequest) ProtoReflect

func (x *UploadThumbnailRequest) ProtoReflect() protoreflect.Message

func (*UploadThumbnailRequest) Reset

func (x *UploadThumbnailRequest) Reset()

func (*UploadThumbnailRequest) String

func (x *UploadThumbnailRequest) String() string

type UploadThumbnailResponse

type UploadThumbnailResponse struct {
	// contains filtered or unexported fields
}

func (*UploadThumbnailResponse) Descriptor deprecated

func (*UploadThumbnailResponse) Descriptor() ([]byte, []int)

Deprecated: Use UploadThumbnailResponse.ProtoReflect.Descriptor instead.

func (*UploadThumbnailResponse) ProtoMessage

func (*UploadThumbnailResponse) ProtoMessage()

func (*UploadThumbnailResponse) ProtoReflect

func (x *UploadThumbnailResponse) ProtoReflect() protoreflect.Message

func (*UploadThumbnailResponse) Reset

func (x *UploadThumbnailResponse) Reset()

func (*UploadThumbnailResponse) String

func (x *UploadThumbnailResponse) String() string

Jump to